# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class EncodingOutputPathsSmoothManifest(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 client_manifest_path=None,
                 server_manifest_path=None):
        # type: (string_types, string_types, string_types) -> None

        self._id = None
        self._client_manifest_path = None
        self._server_manifest_path = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if client_manifest_path is not None:
            self.client_manifest_path = client_manifest_path
        if server_manifest_path is not None:
            self.server_manifest_path = server_manifest_path

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'client_manifest_path': 'string_types',
            'server_manifest_path': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'client_manifest_path': 'clientManifestPath',
            'server_manifest_path': 'serverManifestPath'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this EncodingOutputPathsSmoothManifest.

        Id of the Smooth manifest

        :return: The id of this EncodingOutputPathsSmoothManifest.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this EncodingOutputPathsSmoothManifest.

        Id of the Smooth manifest

        :param id_: The id of this EncodingOutputPathsSmoothManifest.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def client_manifest_path(self):
        # type: () -> string_types
        """Gets the client_manifest_path of this EncodingOutputPathsSmoothManifest.

        Path to the client manifest of the Smooth manifest on the given output

        :return: The client_manifest_path of this EncodingOutputPathsSmoothManifest.
        :rtype: string_types
        """
        return self._client_manifest_path

    @client_manifest_path.setter
    def client_manifest_path(self, client_manifest_path):
        # type: (string_types) -> None
        """Sets the client_manifest_path of this EncodingOutputPathsSmoothManifest.

        Path to the client manifest of the Smooth manifest on the given output

        :param client_manifest_path: The client_manifest_path of this EncodingOutputPathsSmoothManifest.
        :type: string_types
        """

        if client_manifest_path is not None:
            if not isinstance(client_manifest_path, string_types):
                raise TypeError("Invalid type for `client_manifest_path`, type has to be `string_types`")

        self._client_manifest_path = client_manifest_path

    @property
    def server_manifest_path(self):
        # type: () -> string_types
        """Gets the server_manifest_path of this EncodingOutputPathsSmoothManifest.

        Path to the server manifest of the Smooth manifest on the given output

        :return: The server_manifest_path of this EncodingOutputPathsSmoothManifest.
        :rtype: string_types
        """
        return self._server_manifest_path

    @server_manifest_path.setter
    def server_manifest_path(self, server_manifest_path):
        # type: (string_types) -> None
        """Sets the server_manifest_path of this EncodingOutputPathsSmoothManifest.

        Path to the server manifest of the Smooth manifest on the given output

        :param server_manifest_path: The server_manifest_path of this EncodingOutputPathsSmoothManifest.
        :type: string_types
        """

        if server_manifest_path is not None:
            if not isinstance(server_manifest_path, string_types):
                raise TypeError("Invalid type for `server_manifest_path`, type has to be `string_types`")

        self._server_manifest_path = server_manifest_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EncodingOutputPathsSmoothManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
import pprint
import six


class UnsharpFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 luma_matrix_horizontal_size=None,
                 luma_matrix_vertical_size=None,
                 luma_effect_strength=None,
                 chroma_matrix_horizontal_size=None,
                 chroma_matrix_vertical_size=None,
                 chroma_effect_strength=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, float, int, int, float) -> None
        super(UnsharpFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._luma_matrix_horizontal_size = None
        self._luma_matrix_vertical_size = None
        self._luma_effect_strength = None
        self._chroma_matrix_horizontal_size = None
        self._chroma_matrix_vertical_size = None
        self._chroma_effect_strength = None
        self.discriminator = None

        if luma_matrix_horizontal_size is not None:
            self.luma_matrix_horizontal_size = luma_matrix_horizontal_size
        if luma_matrix_vertical_size is not None:
            self.luma_matrix_vertical_size = luma_matrix_vertical_size
        if luma_effect_strength is not None:
            self.luma_effect_strength = luma_effect_strength
        if chroma_matrix_horizontal_size is not None:
            self.chroma_matrix_horizontal_size = chroma_matrix_horizontal_size
        if chroma_matrix_vertical_size is not None:
            self.chroma_matrix_vertical_size = chroma_matrix_vertical_size
        if chroma_effect_strength is not None:
            self.chroma_effect_strength = chroma_effect_strength

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(UnsharpFilter, self), 'openapi_types'):
            types = getattr(super(UnsharpFilter, self), 'openapi_types')

        types.update({
            'luma_matrix_horizontal_size': 'int',
            'luma_matrix_vertical_size': 'int',
            'luma_effect_strength': 'float',
            'chroma_matrix_horizontal_size': 'int',
            'chroma_matrix_vertical_size': 'int',
            'chroma_effect_strength': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(UnsharpFilter, self), 'attribute_map'):
            attributes = getattr(super(UnsharpFilter, self), 'attribute_map')

        attributes.update({
            'luma_matrix_horizontal_size': 'lumaMatrixHorizontalSize',
            'luma_matrix_vertical_size': 'lumaMatrixVerticalSize',
            'luma_effect_strength': 'lumaEffectStrength',
            'chroma_matrix_horizontal_size': 'chromaMatrixHorizontalSize',
            'chroma_matrix_vertical_size': 'chromaMatrixVerticalSize',
            'chroma_effect_strength': 'chromaEffectStrength'
        })
        return attributes

    @property
    def luma_matrix_horizontal_size(self):
        # type: () -> int
        """Gets the luma_matrix_horizontal_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :return: The luma_matrix_horizontal_size of this UnsharpFilter.
        :rtype: int
        """
        return self._luma_matrix_horizontal_size

    @luma_matrix_horizontal_size.setter
    def luma_matrix_horizontal_size(self, luma_matrix_horizontal_size):
        # type: (int) -> None
        """Sets the luma_matrix_horizontal_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :param luma_matrix_horizontal_size: The luma_matrix_horizontal_size of this UnsharpFilter.
        :type: int
        """

        if luma_matrix_horizontal_size is not None:
            if not isinstance(luma_matrix_horizontal_size, int):
                raise TypeError("Invalid type for `luma_matrix_horizontal_size`, type has to be `int`")

        self._luma_matrix_horizontal_size = luma_matrix_horizontal_size

    @property
    def luma_matrix_vertical_size(self):
        # type: () -> int
        """Gets the luma_matrix_vertical_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :return: The luma_matrix_vertical_size of this UnsharpFilter.
        :rtype: int
        """
        return self._luma_matrix_vertical_size

    @luma_matrix_vertical_size.setter
    def luma_matrix_vertical_size(self, luma_matrix_vertical_size):
        # type: (int) -> None
        """Sets the luma_matrix_vertical_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :param luma_matrix_vertical_size: The luma_matrix_vertical_size of this UnsharpFilter.
        :type: int
        """

        if luma_matrix_vertical_size is not None:
            if not isinstance(luma_matrix_vertical_size, int):
                raise TypeError("Invalid type for `luma_matrix_vertical_size`, type has to be `int`")

        self._luma_matrix_vertical_size = luma_matrix_vertical_size

    @property
    def luma_effect_strength(self):
        # type: () -> float
        """Gets the luma_effect_strength of this UnsharpFilter.

        Negative value: blur, positive value: sharpen, floating point number, valid value range: -1.5 - 1.5

        :return: The luma_effect_strength of this UnsharpFilter.
        :rtype: float
        """
        return self._luma_effect_strength

    @luma_effect_strength.setter
    def luma_effect_strength(self, luma_effect_strength):
        # type: (float) -> None
        """Sets the luma_effect_strength of this UnsharpFilter.

        Negative value: blur, positive value: sharpen, floating point number, valid value range: -1.5 - 1.5

        :param luma_effect_strength: The luma_effect_strength of this UnsharpFilter.
        :type: float
        """

        if luma_effect_strength is not None:
            if not isinstance(luma_effect_strength, (float, int)):
                raise TypeError("Invalid type for `luma_effect_strength`, type has to be `float`")

        self._luma_effect_strength = luma_effect_strength

    @property
    def chroma_matrix_horizontal_size(self):
        # type: () -> int
        """Gets the chroma_matrix_horizontal_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :return: The chroma_matrix_horizontal_size of this UnsharpFilter.
        :rtype: int
        """
        return self._chroma_matrix_horizontal_size

    @chroma_matrix_horizontal_size.setter
    def chroma_matrix_horizontal_size(self, chroma_matrix_horizontal_size):
        # type: (int) -> None
        """Sets the chroma_matrix_horizontal_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :param chroma_matrix_horizontal_size: The chroma_matrix_horizontal_size of this UnsharpFilter.
        :type: int
        """

        if chroma_matrix_horizontal_size is not None:
            if not isinstance(chroma_matrix_horizontal_size, int):
                raise TypeError("Invalid type for `chroma_matrix_horizontal_size`, type has to be `int`")

        self._chroma_matrix_horizontal_size = chroma_matrix_horizontal_size

    @property
    def chroma_matrix_vertical_size(self):
        # type: () -> int
        """Gets the chroma_matrix_vertical_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :return: The chroma_matrix_vertical_size of this UnsharpFilter.
        :rtype: int
        """
        return self._chroma_matrix_vertical_size

    @chroma_matrix_vertical_size.setter
    def chroma_matrix_vertical_size(self, chroma_matrix_vertical_size):
        # type: (int) -> None
        """Sets the chroma_matrix_vertical_size of this UnsharpFilter.

        Must be an odd integer between 3 and 23

        :param chroma_matrix_vertical_size: The chroma_matrix_vertical_size of this UnsharpFilter.
        :type: int
        """

        if chroma_matrix_vertical_size is not None:
            if not isinstance(chroma_matrix_vertical_size, int):
                raise TypeError("Invalid type for `chroma_matrix_vertical_size`, type has to be `int`")

        self._chroma_matrix_vertical_size = chroma_matrix_vertical_size

    @property
    def chroma_effect_strength(self):
        # type: () -> float
        """Gets the chroma_effect_strength of this UnsharpFilter.

        Negative value: blur, positive value: sharpen, floating point number, valid value range: -1.5 - 1.5

        :return: The chroma_effect_strength of this UnsharpFilter.
        :rtype: float
        """
        return self._chroma_effect_strength

    @chroma_effect_strength.setter
    def chroma_effect_strength(self, chroma_effect_strength):
        # type: (float) -> None
        """Sets the chroma_effect_strength of this UnsharpFilter.

        Negative value: blur, positive value: sharpen, floating point number, valid value range: -1.5 - 1.5

        :param chroma_effect_strength: The chroma_effect_strength of this UnsharpFilter.
        :type: float
        """

        if chroma_effect_strength is not None:
            if not isinstance(chroma_effect_strength, (float, int)):
                raise TypeError("Invalid type for `chroma_effect_strength`, type has to be `float`")

        self._chroma_effect_strength = chroma_effect_strength

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(UnsharpFilter, self), "to_dict"):
            result = super(UnsharpFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UnsharpFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.organization import Organization
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.update_organization_request import UpdateOrganizationRequest
from bitmovin_api_sdk.account.organizations.sub_organizations.sub_organizations_api import SubOrganizationsApi
from bitmovin_api_sdk.account.organizations.tenants.tenants_api import TenantsApi
from bitmovin_api_sdk.account.organizations.invitations.invitations_api import InvitationsApi
from bitmovin_api_sdk.account.organizations.groups.groups_api import GroupsApi


class OrganizationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OrganizationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sub_organizations = SubOrganizationsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.tenants = TenantsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.invitations = InvitationsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.groups = GroupsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, organization, **kwargs):
        # type: (Organization, dict) -> Organization
        """Add Organization

        :param organization: Organization Details
        :type organization: Organization, required
        :return: Organization Details
        :rtype: Organization
        """

        return self.api_client.post(
            '/account/organizations',
            organization,
            type=Organization,
            **kwargs
        )

    def get(self, organization_id, **kwargs):
        # type: (string_types, dict) -> Organization
        """Organization Details

        :param organization_id: ID of the organization
        :type organization_id: string_types, required
        :return: Organization details
        :rtype: Organization
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}',
            path_params={'organization_id': organization_id},
            type=Organization,
            **kwargs
        )

    def list(self, **kwargs):
        # type: (dict) -> Organization
        """List Organizations

        :return: List of organizations
        :rtype: Organization
        """

        return self.api_client.get(
            '/account/organizations',
            pagination_response=True,
            type=Organization,
            **kwargs
        )

    def update(self, organization_id, update_organization_request, **kwargs):
        # type: (string_types, UpdateOrganizationRequest, dict) -> Organization
        """Update Organization

        :param organization_id: ID of the organization
        :type organization_id: string_types, required
        :param update_organization_request: Organization Details fields to be updated
        :type update_organization_request: UpdateOrganizationRequest, required
        :return: Organization Details
        :rtype: Organization
        """

        return self.api_client.put(
            '/account/organizations/{organization_id}',
            update_organization_request,
            path_params={'organization_id': organization_id},
            type=Organization,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.caption_character_encoding import CaptionCharacterEncoding
from bitmovin_api_sdk.models.cea608_channel_type import Cea608ChannelType
from bitmovin_api_sdk.models.input_path import InputPath
import pprint
import six


class SrtToCea608708Caption(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_=None,
                 cc_channel=None,
                 character_encoding=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, InputPath, Cea608ChannelType, CaptionCharacterEncoding) -> None
        super(SrtToCea608708Caption, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input = None
        self._cc_channel = None
        self._character_encoding = None
        self.discriminator = None

        if input_ is not None:
            self.input = input_
        if cc_channel is not None:
            self.cc_channel = cc_channel
        if character_encoding is not None:
            self.character_encoding = character_encoding

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SrtToCea608708Caption, self), 'openapi_types'):
            types = getattr(super(SrtToCea608708Caption, self), 'openapi_types')

        types.update({
            'input': 'InputPath',
            'cc_channel': 'Cea608ChannelType',
            'character_encoding': 'CaptionCharacterEncoding'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SrtToCea608708Caption, self), 'attribute_map'):
            attributes = getattr(super(SrtToCea608708Caption, self), 'attribute_map')

        attributes.update({
            'input': 'input',
            'cc_channel': 'ccChannel',
            'character_encoding': 'characterEncoding'
        })
        return attributes

    @property
    def input(self):
        # type: () -> InputPath
        """Gets the input of this SrtToCea608708Caption.

        Input location of the SRT file (required)

        :return: The input of this SrtToCea608708Caption.
        :rtype: InputPath
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (InputPath) -> None
        """Sets the input of this SrtToCea608708Caption.

        Input location of the SRT file (required)

        :param input_: The input of this SrtToCea608708Caption.
        :type: InputPath
        """

        if input_ is not None:
            if not isinstance(input_, InputPath):
                raise TypeError("Invalid type for `input`, type has to be `InputPath`")

        self._input = input_

    @property
    def cc_channel(self):
        # type: () -> Cea608ChannelType
        """Gets the cc_channel of this SrtToCea608708Caption.

        The channel number to embed the CEA subtitles in (required)

        :return: The cc_channel of this SrtToCea608708Caption.
        :rtype: Cea608ChannelType
        """
        return self._cc_channel

    @cc_channel.setter
    def cc_channel(self, cc_channel):
        # type: (Cea608ChannelType) -> None
        """Sets the cc_channel of this SrtToCea608708Caption.

        The channel number to embed the CEA subtitles in (required)

        :param cc_channel: The cc_channel of this SrtToCea608708Caption.
        :type: Cea608ChannelType
        """

        if cc_channel is not None:
            if not isinstance(cc_channel, Cea608ChannelType):
                raise TypeError("Invalid type for `cc_channel`, type has to be `Cea608ChannelType`")

        self._cc_channel = cc_channel

    @property
    def character_encoding(self):
        # type: () -> CaptionCharacterEncoding
        """Gets the character_encoding of this SrtToCea608708Caption.

        Character encoding of the input SRT file (required)

        :return: The character_encoding of this SrtToCea608708Caption.
        :rtype: CaptionCharacterEncoding
        """
        return self._character_encoding

    @character_encoding.setter
    def character_encoding(self, character_encoding):
        # type: (CaptionCharacterEncoding) -> None
        """Sets the character_encoding of this SrtToCea608708Caption.

        Character encoding of the input SRT file (required)

        :param character_encoding: The character_encoding of this SrtToCea608708Caption.
        :type: CaptionCharacterEncoding
        """

        if character_encoding is not None:
            if not isinstance(character_encoding, CaptionCharacterEncoding):
                raise TypeError("Invalid type for `character_encoding`, type has to be `CaptionCharacterEncoding`")

        self._character_encoding = character_encoding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SrtToCea608708Caption, self), "to_dict"):
            result = super(SrtToCea608708Caption, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SrtToCea608708Caption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.filters.scale.scale_api import ScaleApi
from bitmovin_api_sdk.encoding.filters.scale.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.scale.scale_filter_list_query_params import ScaleFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Vp8ArnrType(Enum):
    BACKWARD = "BACKWARD"
    FORWARD = "FORWARD"
    CENTERED = "CENTERED"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ai_scene_analysis import AiSceneAnalysis
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.manifest_generator import ManifestGenerator
from bitmovin_api_sdk.models.per_title import PerTitle
from bitmovin_api_sdk.models.scheduling import Scheduling
from bitmovin_api_sdk.models.trimming import Trimming
from bitmovin_api_sdk.models.tweaks import Tweaks
import pprint
import six


class StartEncodingRequest(object):
    @poscheck_model
    def __init__(self,
                 trimming=None,
                 scheduling=None,
                 tweaks=None,
                 handle_variable_input_fps=None,
                 encoding_mode=None,
                 preview_dash_manifests=None,
                 preview_hls_manifests=None,
                 vod_dash_manifests=None,
                 vod_hls_manifests=None,
                 vod_smooth_manifests=None,
                 manifest_generator=None,
                 per_title=None,
                 ai_scene_analysis=None):
        # type: (Trimming, Scheduling, Tweaks, bool, EncodingMode, list[ManifestResource], list[ManifestResource], list[ManifestResource], list[ManifestResource], list[ManifestResource], ManifestGenerator, PerTitle, AiSceneAnalysis) -> None

        self._trimming = None
        self._scheduling = None
        self._tweaks = None
        self._handle_variable_input_fps = None
        self._encoding_mode = None
        self._preview_dash_manifests = list()
        self._preview_hls_manifests = list()
        self._vod_dash_manifests = list()
        self._vod_hls_manifests = list()
        self._vod_smooth_manifests = list()
        self._manifest_generator = None
        self._per_title = None
        self._ai_scene_analysis = None
        self.discriminator = None

        if trimming is not None:
            self.trimming = trimming
        if scheduling is not None:
            self.scheduling = scheduling
        if tweaks is not None:
            self.tweaks = tweaks
        if handle_variable_input_fps is not None:
            self.handle_variable_input_fps = handle_variable_input_fps
        if encoding_mode is not None:
            self.encoding_mode = encoding_mode
        if preview_dash_manifests is not None:
            self.preview_dash_manifests = preview_dash_manifests
        if preview_hls_manifests is not None:
            self.preview_hls_manifests = preview_hls_manifests
        if vod_dash_manifests is not None:
            self.vod_dash_manifests = vod_dash_manifests
        if vod_hls_manifests is not None:
            self.vod_hls_manifests = vod_hls_manifests
        if vod_smooth_manifests is not None:
            self.vod_smooth_manifests = vod_smooth_manifests
        if manifest_generator is not None:
            self.manifest_generator = manifest_generator
        if per_title is not None:
            self.per_title = per_title
        if ai_scene_analysis is not None:
            self.ai_scene_analysis = ai_scene_analysis

    @property
    def openapi_types(self):
        types = {
            'trimming': 'Trimming',
            'scheduling': 'Scheduling',
            'tweaks': 'Tweaks',
            'handle_variable_input_fps': 'bool',
            'encoding_mode': 'EncodingMode',
            'preview_dash_manifests': 'list[ManifestResource]',
            'preview_hls_manifests': 'list[ManifestResource]',
            'vod_dash_manifests': 'list[ManifestResource]',
            'vod_hls_manifests': 'list[ManifestResource]',
            'vod_smooth_manifests': 'list[ManifestResource]',
            'manifest_generator': 'ManifestGenerator',
            'per_title': 'PerTitle',
            'ai_scene_analysis': 'AiSceneAnalysis'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'trimming': 'trimming',
            'scheduling': 'scheduling',
            'tweaks': 'tweaks',
            'handle_variable_input_fps': 'handleVariableInputFps',
            'encoding_mode': 'encodingMode',
            'preview_dash_manifests': 'previewDashManifests',
            'preview_hls_manifests': 'previewHlsManifests',
            'vod_dash_manifests': 'vodDashManifests',
            'vod_hls_manifests': 'vodHlsManifests',
            'vod_smooth_manifests': 'vodSmoothManifests',
            'manifest_generator': 'manifestGenerator',
            'per_title': 'perTitle',
            'ai_scene_analysis': 'aiSceneAnalysis'
        }
        return attributes

    @property
    def trimming(self):
        # type: () -> Trimming
        """Gets the trimming of this StartEncodingRequest.

        Allows to encode only part of the input. Defines start (offset) and duration of the desired section. This is not allowed when the Encoding uses any kind of Input Stream resource.

        :return: The trimming of this StartEncodingRequest.
        :rtype: Trimming
        """
        return self._trimming

    @trimming.setter
    def trimming(self, trimming):
        # type: (Trimming) -> None
        """Sets the trimming of this StartEncodingRequest.

        Allows to encode only part of the input. Defines start (offset) and duration of the desired section. This is not allowed when the Encoding uses any kind of Input Stream resource.

        :param trimming: The trimming of this StartEncodingRequest.
        :type: Trimming
        """

        if trimming is not None:
            if not isinstance(trimming, Trimming):
                raise TypeError("Invalid type for `trimming`, type has to be `Trimming`")

        self._trimming = trimming

    @property
    def scheduling(self):
        # type: () -> Scheduling
        """Gets the scheduling of this StartEncodingRequest.

        Scheduling parameters of the encoding.

        :return: The scheduling of this StartEncodingRequest.
        :rtype: Scheduling
        """
        return self._scheduling

    @scheduling.setter
    def scheduling(self, scheduling):
        # type: (Scheduling) -> None
        """Sets the scheduling of this StartEncodingRequest.

        Scheduling parameters of the encoding.

        :param scheduling: The scheduling of this StartEncodingRequest.
        :type: Scheduling
        """

        if scheduling is not None:
            if not isinstance(scheduling, Scheduling):
                raise TypeError("Invalid type for `scheduling`, type has to be `Scheduling`")

        self._scheduling = scheduling

    @property
    def tweaks(self):
        # type: () -> Tweaks
        """Gets the tweaks of this StartEncodingRequest.

        Special tweaks for your encoding job.

        :return: The tweaks of this StartEncodingRequest.
        :rtype: Tweaks
        """
        return self._tweaks

    @tweaks.setter
    def tweaks(self, tweaks):
        # type: (Tweaks) -> None
        """Sets the tweaks of this StartEncodingRequest.

        Special tweaks for your encoding job.

        :param tweaks: The tweaks of this StartEncodingRequest.
        :type: Tweaks
        """

        if tweaks is not None:
            if not isinstance(tweaks, Tweaks):
                raise TypeError("Invalid type for `tweaks`, type has to be `Tweaks`")

        self._tweaks = tweaks

    @property
    def handle_variable_input_fps(self):
        # type: () -> bool
        """Gets the handle_variable_input_fps of this StartEncodingRequest.

        Enable frame dropping/duplication to handle variable frames per seconds of video input streams

        :return: The handle_variable_input_fps of this StartEncodingRequest.
        :rtype: bool
        """
        return self._handle_variable_input_fps

    @handle_variable_input_fps.setter
    def handle_variable_input_fps(self, handle_variable_input_fps):
        # type: (bool) -> None
        """Sets the handle_variable_input_fps of this StartEncodingRequest.

        Enable frame dropping/duplication to handle variable frames per seconds of video input streams

        :param handle_variable_input_fps: The handle_variable_input_fps of this StartEncodingRequest.
        :type: bool
        """

        if handle_variable_input_fps is not None:
            if not isinstance(handle_variable_input_fps, bool):
                raise TypeError("Invalid type for `handle_variable_input_fps`, type has to be `bool`")

        self._handle_variable_input_fps = handle_variable_input_fps

    @property
    def encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the encoding_mode of this StartEncodingRequest.

        The pass mode of the encoding. Must only be set when `encodingMode` is not set on any codec configuration used by this encoding.

        :return: The encoding_mode of this StartEncodingRequest.
        :rtype: EncodingMode
        """
        return self._encoding_mode

    @encoding_mode.setter
    def encoding_mode(self, encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the encoding_mode of this StartEncodingRequest.

        The pass mode of the encoding. Must only be set when `encodingMode` is not set on any codec configuration used by this encoding.

        :param encoding_mode: The encoding_mode of this StartEncodingRequest.
        :type: EncodingMode
        """

        if encoding_mode is not None:
            if not isinstance(encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `encoding_mode`, type has to be `EncodingMode`")

        self._encoding_mode = encoding_mode

    @property
    def preview_dash_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the preview_dash_manifests of this StartEncodingRequest.

        DASH manifests to be generated for previewing while the encoding is still running. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The preview_dash_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._preview_dash_manifests

    @preview_dash_manifests.setter
    def preview_dash_manifests(self, preview_dash_manifests):
        # type: (list) -> None
        """Sets the preview_dash_manifests of this StartEncodingRequest.

        DASH manifests to be generated for previewing while the encoding is still running. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param preview_dash_manifests: The preview_dash_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if preview_dash_manifests is not None:
            if not isinstance(preview_dash_manifests, list):
                raise TypeError("Invalid type for `preview_dash_manifests`, type has to be `list[ManifestResource]`")

        self._preview_dash_manifests = preview_dash_manifests

    @property
    def preview_hls_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the preview_hls_manifests of this StartEncodingRequest.

        HLS manifests to be generated for previewing while the encoding is still running. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The preview_hls_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._preview_hls_manifests

    @preview_hls_manifests.setter
    def preview_hls_manifests(self, preview_hls_manifests):
        # type: (list) -> None
        """Sets the preview_hls_manifests of this StartEncodingRequest.

        HLS manifests to be generated for previewing while the encoding is still running. See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param preview_hls_manifests: The preview_hls_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if preview_hls_manifests is not None:
            if not isinstance(preview_hls_manifests, list):
                raise TypeError("Invalid type for `preview_hls_manifests`, type has to be `list[ManifestResource]`")

        self._preview_hls_manifests = preview_hls_manifests

    @property
    def vod_dash_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the vod_dash_manifests of this StartEncodingRequest.

        DASH manifests to be generated right after encoding (just-in-time). See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The vod_dash_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._vod_dash_manifests

    @vod_dash_manifests.setter
    def vod_dash_manifests(self, vod_dash_manifests):
        # type: (list) -> None
        """Sets the vod_dash_manifests of this StartEncodingRequest.

        DASH manifests to be generated right after encoding (just-in-time). See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param vod_dash_manifests: The vod_dash_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if vod_dash_manifests is not None:
            if not isinstance(vod_dash_manifests, list):
                raise TypeError("Invalid type for `vod_dash_manifests`, type has to be `list[ManifestResource]`")

        self._vod_dash_manifests = vod_dash_manifests

    @property
    def vod_hls_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the vod_hls_manifests of this StartEncodingRequest.

        HLS manifests to be generated right after encoding (just-in-time). See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The vod_hls_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._vod_hls_manifests

    @vod_hls_manifests.setter
    def vod_hls_manifests(self, vod_hls_manifests):
        # type: (list) -> None
        """Sets the vod_hls_manifests of this StartEncodingRequest.

        HLS manifests to be generated right after encoding (just-in-time). See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param vod_hls_manifests: The vod_hls_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if vod_hls_manifests is not None:
            if not isinstance(vod_hls_manifests, list):
                raise TypeError("Invalid type for `vod_hls_manifests`, type has to be `list[ManifestResource]`")

        self._vod_hls_manifests = vod_hls_manifests

    @property
    def vod_smooth_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the vod_smooth_manifests of this StartEncodingRequest.

        Smooth Streaming manifests to be generated right after encoding (just-in-time). See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :return: The vod_smooth_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._vod_smooth_manifests

    @vod_smooth_manifests.setter
    def vod_smooth_manifests(self, vod_smooth_manifests):
        # type: (list) -> None
        """Sets the vod_smooth_manifests of this StartEncodingRequest.

        Smooth Streaming manifests to be generated right after encoding (just-in-time). See [documentation](https://developer.bitmovin.com/encoding/docs/how-to-create-manifests-for-your-encodings#just-in-time-jit)

        :param vod_smooth_manifests: The vod_smooth_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if vod_smooth_manifests is not None:
            if not isinstance(vod_smooth_manifests, list):
                raise TypeError("Invalid type for `vod_smooth_manifests`, type has to be `list[ManifestResource]`")

        self._vod_smooth_manifests = vod_smooth_manifests

    @property
    def manifest_generator(self):
        # type: () -> ManifestGenerator
        """Gets the manifest_generator of this StartEncodingRequest.

        Major version of the manifest generator to be used for manifests referenced in this request (by properties vodDashManifests, vodHlsManifests, vodSmoothManifests, previewDashManifests, previewHlsManifests). `V2` is available for encoder versions 2.70.0 and above and is the recommended option. The default value depends on the sign-up date of your organization. See [documentation](https://developer.bitmovin.com/encoding/docs/manifest-generator-v2) page for a detailed explanation. 

        :return: The manifest_generator of this StartEncodingRequest.
        :rtype: ManifestGenerator
        """
        return self._manifest_generator

    @manifest_generator.setter
    def manifest_generator(self, manifest_generator):
        # type: (ManifestGenerator) -> None
        """Sets the manifest_generator of this StartEncodingRequest.

        Major version of the manifest generator to be used for manifests referenced in this request (by properties vodDashManifests, vodHlsManifests, vodSmoothManifests, previewDashManifests, previewHlsManifests). `V2` is available for encoder versions 2.70.0 and above and is the recommended option. The default value depends on the sign-up date of your organization. See [documentation](https://developer.bitmovin.com/encoding/docs/manifest-generator-v2) page for a detailed explanation. 

        :param manifest_generator: The manifest_generator of this StartEncodingRequest.
        :type: ManifestGenerator
        """

        if manifest_generator is not None:
            if not isinstance(manifest_generator, ManifestGenerator):
                raise TypeError("Invalid type for `manifest_generator`, type has to be `ManifestGenerator`")

        self._manifest_generator = manifest_generator

    @property
    def per_title(self):
        # type: () -> PerTitle
        """Gets the per_title of this StartEncodingRequest.

        Per-Title settings

        :return: The per_title of this StartEncodingRequest.
        :rtype: PerTitle
        """
        return self._per_title

    @per_title.setter
    def per_title(self, per_title):
        # type: (PerTitle) -> None
        """Sets the per_title of this StartEncodingRequest.

        Per-Title settings

        :param per_title: The per_title of this StartEncodingRequest.
        :type: PerTitle
        """

        if per_title is not None:
            if not isinstance(per_title, PerTitle):
                raise TypeError("Invalid type for `per_title`, type has to be `PerTitle`")

        self._per_title = per_title

    @property
    def ai_scene_analysis(self):
        # type: () -> AiSceneAnalysis
        """Gets the ai_scene_analysis of this StartEncodingRequest.

        AI scene analysis settings

        :return: The ai_scene_analysis of this StartEncodingRequest.
        :rtype: AiSceneAnalysis
        """
        return self._ai_scene_analysis

    @ai_scene_analysis.setter
    def ai_scene_analysis(self, ai_scene_analysis):
        # type: (AiSceneAnalysis) -> None
        """Sets the ai_scene_analysis of this StartEncodingRequest.

        AI scene analysis settings

        :param ai_scene_analysis: The ai_scene_analysis of this StartEncodingRequest.
        :type: AiSceneAnalysis
        """

        if ai_scene_analysis is not None:
            if not isinstance(ai_scene_analysis, AiSceneAnalysis):
                raise TypeError("Invalid type for `ai_scene_analysis`, type has to be `AiSceneAnalysis`")

        self._ai_scene_analysis = ai_scene_analysis

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartEncodingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.inputs.https.https_api import HttpsApi
from bitmovin_api_sdk.encoding.inputs.https.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.https.https_input_list_query_params import HttpsInputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.play_ready_additional_information import PlayReadyAdditionalInformation
import pprint
import six


class CencPlayReady(object):
    @poscheck_model
    def __init__(self,
                 la_url=None,
                 pssh=None,
                 additional_information=None):
        # type: (string_types, string_types, PlayReadyAdditionalInformation) -> None

        self._la_url = None
        self._pssh = None
        self._additional_information = None
        self.discriminator = None

        if la_url is not None:
            self.la_url = la_url
        if pssh is not None:
            self.pssh = pssh
        if additional_information is not None:
            self.additional_information = additional_information

    @property
    def openapi_types(self):
        types = {
            'la_url': 'string_types',
            'pssh': 'string_types',
            'additional_information': 'PlayReadyAdditionalInformation'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'la_url': 'laUrl',
            'pssh': 'pssh',
            'additional_information': 'additionalInformation'
        }
        return attributes

    @property
    def la_url(self):
        # type: () -> string_types
        """Gets the la_url of this CencPlayReady.

        Url of the license server. Either the laUrl or the pssh needs to be provided.

        :return: The la_url of this CencPlayReady.
        :rtype: string_types
        """
        return self._la_url

    @la_url.setter
    def la_url(self, la_url):
        # type: (string_types) -> None
        """Sets the la_url of this CencPlayReady.

        Url of the license server. Either the laUrl or the pssh needs to be provided.

        :param la_url: The la_url of this CencPlayReady.
        :type: string_types
        """

        if la_url is not None:
            if not isinstance(la_url, string_types):
                raise TypeError("Invalid type for `la_url`, type has to be `string_types`")

        self._la_url = la_url

    @property
    def pssh(self):
        # type: () -> string_types
        """Gets the pssh of this CencPlayReady.

        Base64 encoded pssh payload.

        :return: The pssh of this CencPlayReady.
        :rtype: string_types
        """
        return self._pssh

    @pssh.setter
    def pssh(self, pssh):
        # type: (string_types) -> None
        """Sets the pssh of this CencPlayReady.

        Base64 encoded pssh payload.

        :param pssh: The pssh of this CencPlayReady.
        :type: string_types
        """

        if pssh is not None:
            if not isinstance(pssh, string_types):
                raise TypeError("Invalid type for `pssh`, type has to be `string_types`")

        self._pssh = pssh

    @property
    def additional_information(self):
        # type: () -> PlayReadyAdditionalInformation
        """Gets the additional_information of this CencPlayReady.


        :return: The additional_information of this CencPlayReady.
        :rtype: PlayReadyAdditionalInformation
        """
        return self._additional_information

    @additional_information.setter
    def additional_information(self, additional_information):
        # type: (PlayReadyAdditionalInformation) -> None
        """Sets the additional_information of this CencPlayReady.


        :param additional_information: The additional_information of this CencPlayReady.
        :type: PlayReadyAdditionalInformation
        """

        if additional_information is not None:
            if not isinstance(additional_information, PlayReadyAdditionalInformation):
                raise TypeError("Invalid type for `additional_information`, type has to be `PlayReadyAdditionalInformation`")

        self._additional_information = additional_information

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CencPlayReady):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.notifications.emails.usage_reports.usage_reports_api import UsageReportsApi
from bitmovin_api_sdk.notifications.emails.usage_reports.email_notification_list_query_params import EmailNotificationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.hls_manifest_ad_marker_settings import HlsManifestAdMarkerSettings
from bitmovin_api_sdk.models.program_date_time_settings import ProgramDateTimeSettings
import pprint
import six


class LiveHlsManifest(object):
    @poscheck_model
    def __init__(self,
                 manifest_id=None,
                 timeshift=None,
                 live_edge_offset=None,
                 insert_program_date_time=None,
                 program_date_time_settings=None,
                 ad_marker_settings=None):
        # type: (string_types, float, float, bool, ProgramDateTimeSettings, HlsManifestAdMarkerSettings) -> None

        self._manifest_id = None
        self._timeshift = None
        self._live_edge_offset = None
        self._insert_program_date_time = None
        self._program_date_time_settings = None
        self._ad_marker_settings = None
        self.discriminator = None

        if manifest_id is not None:
            self.manifest_id = manifest_id
        if timeshift is not None:
            self.timeshift = timeshift
        if live_edge_offset is not None:
            self.live_edge_offset = live_edge_offset
        if insert_program_date_time is not None:
            self.insert_program_date_time = insert_program_date_time
        if program_date_time_settings is not None:
            self.program_date_time_settings = program_date_time_settings
        if ad_marker_settings is not None:
            self.ad_marker_settings = ad_marker_settings

    @property
    def openapi_types(self):
        types = {
            'manifest_id': 'string_types',
            'timeshift': 'float',
            'live_edge_offset': 'float',
            'insert_program_date_time': 'bool',
            'program_date_time_settings': 'ProgramDateTimeSettings',
            'ad_marker_settings': 'HlsManifestAdMarkerSettings'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'manifest_id': 'manifestId',
            'timeshift': 'timeshift',
            'live_edge_offset': 'liveEdgeOffset',
            'insert_program_date_time': 'insertProgramDateTime',
            'program_date_time_settings': 'programDateTimeSettings',
            'ad_marker_settings': 'adMarkerSettings'
        }
        return attributes

    @property
    def manifest_id(self):
        # type: () -> string_types
        """Gets the manifest_id of this LiveHlsManifest.

        HLS manifest id (required)

        :return: The manifest_id of this LiveHlsManifest.
        :rtype: string_types
        """
        return self._manifest_id

    @manifest_id.setter
    def manifest_id(self, manifest_id):
        # type: (string_types) -> None
        """Sets the manifest_id of this LiveHlsManifest.

        HLS manifest id (required)

        :param manifest_id: The manifest_id of this LiveHlsManifest.
        :type: string_types
        """

        if manifest_id is not None:
            if not isinstance(manifest_id, string_types):
                raise TypeError("Invalid type for `manifest_id`, type has to be `string_types`")

        self._manifest_id = manifest_id

    @property
    def timeshift(self):
        # type: () -> float
        """Gets the timeshift of this LiveHlsManifest.

        Timeshift in seconds. We recommend to use a timeshift value not greater than 3 hours (10800.0 seconds). Longer values could negatively impact the manifest update frequency. 

        :return: The timeshift of this LiveHlsManifest.
        :rtype: float
        """
        return self._timeshift

    @timeshift.setter
    def timeshift(self, timeshift):
        # type: (float) -> None
        """Sets the timeshift of this LiveHlsManifest.

        Timeshift in seconds. We recommend to use a timeshift value not greater than 3 hours (10800.0 seconds). Longer values could negatively impact the manifest update frequency. 

        :param timeshift: The timeshift of this LiveHlsManifest.
        :type: float
        """

        if timeshift is not None:
            if not isinstance(timeshift, (float, int)):
                raise TypeError("Invalid type for `timeshift`, type has to be `float`")

        self._timeshift = timeshift

    @property
    def live_edge_offset(self):
        # type: () -> float
        """Gets the live_edge_offset of this LiveHlsManifest.

        Live edge offset in seconds

        :return: The live_edge_offset of this LiveHlsManifest.
        :rtype: float
        """
        return self._live_edge_offset

    @live_edge_offset.setter
    def live_edge_offset(self, live_edge_offset):
        # type: (float) -> None
        """Sets the live_edge_offset of this LiveHlsManifest.

        Live edge offset in seconds

        :param live_edge_offset: The live_edge_offset of this LiveHlsManifest.
        :type: float
        """

        if live_edge_offset is not None:
            if not isinstance(live_edge_offset, (float, int)):
                raise TypeError("Invalid type for `live_edge_offset`, type has to be `float`")

        self._live_edge_offset = live_edge_offset

    @property
    def insert_program_date_time(self):
        # type: () -> bool
        """Gets the insert_program_date_time of this LiveHlsManifest.

        Specifies if the EXT-X-PROGRAM-DATETIME tag will be included

        :return: The insert_program_date_time of this LiveHlsManifest.
        :rtype: bool
        """
        return self._insert_program_date_time

    @insert_program_date_time.setter
    def insert_program_date_time(self, insert_program_date_time):
        # type: (bool) -> None
        """Sets the insert_program_date_time of this LiveHlsManifest.

        Specifies if the EXT-X-PROGRAM-DATETIME tag will be included

        :param insert_program_date_time: The insert_program_date_time of this LiveHlsManifest.
        :type: bool
        """

        if insert_program_date_time is not None:
            if not isinstance(insert_program_date_time, bool):
                raise TypeError("Invalid type for `insert_program_date_time`, type has to be `bool`")

        self._insert_program_date_time = insert_program_date_time

    @property
    def program_date_time_settings(self):
        # type: () -> ProgramDateTimeSettings
        """Gets the program_date_time_settings of this LiveHlsManifest.

        Configuration for the EXT-X-PROGRAM-DATETIME tag

        :return: The program_date_time_settings of this LiveHlsManifest.
        :rtype: ProgramDateTimeSettings
        """
        return self._program_date_time_settings

    @program_date_time_settings.setter
    def program_date_time_settings(self, program_date_time_settings):
        # type: (ProgramDateTimeSettings) -> None
        """Sets the program_date_time_settings of this LiveHlsManifest.

        Configuration for the EXT-X-PROGRAM-DATETIME tag

        :param program_date_time_settings: The program_date_time_settings of this LiveHlsManifest.
        :type: ProgramDateTimeSettings
        """

        if program_date_time_settings is not None:
            if not isinstance(program_date_time_settings, ProgramDateTimeSettings):
                raise TypeError("Invalid type for `program_date_time_settings`, type has to be `ProgramDateTimeSettings`")

        self._program_date_time_settings = program_date_time_settings

    @property
    def ad_marker_settings(self):
        # type: () -> HlsManifestAdMarkerSettings
        """Gets the ad_marker_settings of this LiveHlsManifest.

        Configuration for tags related to ad markers (e.g. Scte35)

        :return: The ad_marker_settings of this LiveHlsManifest.
        :rtype: HlsManifestAdMarkerSettings
        """
        return self._ad_marker_settings

    @ad_marker_settings.setter
    def ad_marker_settings(self, ad_marker_settings):
        # type: (HlsManifestAdMarkerSettings) -> None
        """Sets the ad_marker_settings of this LiveHlsManifest.

        Configuration for tags related to ad markers (e.g. Scte35)

        :param ad_marker_settings: The ad_marker_settings of this LiveHlsManifest.
        :type: HlsManifestAdMarkerSettings
        """

        if ad_marker_settings is not None:
            if not isinstance(ad_marker_settings, HlsManifestAdMarkerSettings):
                raise TypeError("Invalid type for `ad_marker_settings`, type has to be `HlsManifestAdMarkerSettings`")

        self._ad_marker_settings = ad_marker_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveHlsManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.notification import Notification
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.notifications.emails.usage_reports.usage_reports_api import UsageReportsApi
from bitmovin_api_sdk.notifications.emails.encoding.encoding_api import EncodingApi
from bitmovin_api_sdk.notifications.emails.notification_list_query_params import NotificationListQueryParams


class EmailsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EmailsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.usage_reports = UsageReportsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.encoding = EncodingApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (NotificationListQueryParams, dict) -> Notification
        """List Email Notifications

        :param query_params: Query parameters
        :type query_params: NotificationListQueryParams
        :return: List of Notifications
        :rtype: Notification
        """

        return self.api_client.get(
            '/notifications/emails',
            query_params=query_params,
            pagination_response=True,
            type=Notification,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.custom_xml_element import CustomXmlElement
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.custom_xml_elements.custom_xml_element_list_query_params import CustomXmlElementListQueryParams


class CustomXmlElementsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(CustomXmlElementsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, period_id, custom_xml_element, **kwargs):
        # type: (string_types, string_types, CustomXmlElement, dict) -> CustomXmlElement
        """Add Custom XML Element to Period

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param custom_xml_element: Data of the custom XML element to be added to the period
        :type custom_xml_element: CustomXmlElement, required
        :return: Custom XML Element
        :rtype: CustomXmlElement
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/custom-xml-elements',
            custom_xml_element,
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            type=CustomXmlElement,
            **kwargs
        )

    def delete(self, manifest_id, period_id, custom_xml_element_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Custom XML Element

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param custom_xml_element_id: Id of the Custom XML Element
        :type custom_xml_element_id: string_types, required
        :return: Id of the Custom XML Element
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/custom-xml-elements/{custom_xml_element_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'custom_xml_element_id': custom_xml_element_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, period_id, custom_xml_element_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> CustomXmlElement
        """Custom XML Element Details

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param custom_xml_element_id: Id of the Custom XML Element
        :type custom_xml_element_id: string_types, required
        :return: Custom XML Element details
        :rtype: CustomXmlElement
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/custom-xml-elements/{custom_xml_element_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'custom_xml_element_id': custom_xml_element_id},
            type=CustomXmlElement,
            **kwargs
        )

    def list(self, manifest_id, period_id, query_params=None, **kwargs):
        # type: (string_types, string_types, CustomXmlElementListQueryParams, dict) -> CustomXmlElement
        """List all Custom XML Elements of Period

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param query_params: Query parameters
        :type query_params: CustomXmlElementListQueryParams
        :return: List of Custom XML Elements
        :rtype: CustomXmlElement
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/custom-xml-elements',
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            query_params=query_params,
            pagination_response=True,
            type=CustomXmlElement,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class FragmentedMp4MuxingManifestType(Enum):
    SMOOTH = "SMOOTH"
    DASH_ON_DEMAND = "DASH_ON_DEMAND"
    HLS_BYTE_RANGES = "HLS_BYTE_RANGES"
    NONE = "NONE"
    HLS_BYTE_RANGES_AND_IFRAME_PLAYLIST = "HLS_BYTE_RANGES_AND_IFRAME_PLAYLIST"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyDigitalLoudnessControlRegulationType(Enum):
    EBU_R128 = "EBU_R128"
    ATSC_A85_FIXED = "ATSC_A85_FIXED"
    ATSC_A85_AGILE = "ATSC_A85_AGILE"
    MANUAL = "MANUAL"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.player_channel import PlayerChannel
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.player.channels.versions.versions_api import VersionsApi


class ChannelsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ChannelsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.versions = VersionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, **kwargs):
        # type: (dict) -> PlayerChannel
        """List Player Channels

        :return: Service specific result
        :rtype: PlayerChannel
        """

        return self.api_client.get(
            '/player/channels',
            pagination_response=True,
            type=PlayerChannel,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_atmos.dolby_atmos_api import DolbyAtmosApi
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_atmos.dolby_atmos_ingest_input_stream_list_query_params import DolbyAtmosIngestInputStreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.drm import Drm
import pprint
import six


class FairPlayDrm(Drm):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 outputs=None,
                 key=None,
                 iv=None,
                 uri=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[EncodingOutput], string_types, string_types, string_types) -> None
        super(FairPlayDrm, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, outputs=outputs)

        self._key = None
        self._iv = None
        self._uri = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if iv is not None:
            self.iv = iv
        if uri is not None:
            self.uri = uri

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(FairPlayDrm, self), 'openapi_types'):
            types = getattr(super(FairPlayDrm, self), 'openapi_types')

        types.update({
            'key': 'string_types',
            'iv': 'string_types',
            'uri': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(FairPlayDrm, self), 'attribute_map'):
            attributes = getattr(super(FairPlayDrm, self), 'attribute_map')

        attributes.update({
            'key': 'key',
            'iv': 'iv',
            'uri': 'uri'
        })
        return attributes

    @property
    def key(self):
        # type: () -> string_types
        """Gets the key of this FairPlayDrm.

        16 byte Encryption key, 32 hexadecimal characters (required)

        :return: The key of this FairPlayDrm.
        :rtype: string_types
        """
        return self._key

    @key.setter
    def key(self, key):
        # type: (string_types) -> None
        """Sets the key of this FairPlayDrm.

        16 byte Encryption key, 32 hexadecimal characters (required)

        :param key: The key of this FairPlayDrm.
        :type: string_types
        """

        if key is not None:
            if not isinstance(key, string_types):
                raise TypeError("Invalid type for `key`, type has to be `string_types`")

        self._key = key

    @property
    def iv(self):
        # type: () -> string_types
        """Gets the iv of this FairPlayDrm.

        16 byte initialization vector (required)

        :return: The iv of this FairPlayDrm.
        :rtype: string_types
        """
        return self._iv

    @iv.setter
    def iv(self, iv):
        # type: (string_types) -> None
        """Sets the iv of this FairPlayDrm.

        16 byte initialization vector (required)

        :param iv: The iv of this FairPlayDrm.
        :type: string_types
        """

        if iv is not None:
            if not isinstance(iv, string_types):
                raise TypeError("Invalid type for `iv`, type has to be `string_types`")

        self._iv = iv

    @property
    def uri(self):
        # type: () -> string_types
        """Gets the uri of this FairPlayDrm.

        Url of the licensing server

        :return: The uri of this FairPlayDrm.
        :rtype: string_types
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        # type: (string_types) -> None
        """Sets the uri of this FairPlayDrm.

        Url of the licensing server

        :param uri: The uri of this FairPlayDrm.
        :type: string_types
        """

        if uri is not None:
            if not isinstance(uri, string_types):
                raise TypeError("Invalid type for `uri`, type has to be `string_types`")

        self._uri = uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(FairPlayDrm, self), "to_dict"):
            result = super(FairPlayDrm, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FairPlayDrm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_encoding_event_name import LiveEncodingEventName
import pprint
import six


class LiveEncodingStatsEventDetails(object):
    @poscheck_model
    def __init__(self,
                 event_type=None,
                 message=None,
                 mid_roll_asset_names=None,
                 duration_in_seconds=None):
        # type: (LiveEncodingEventName, string_types, list[string_types], float) -> None

        self._event_type = None
        self._message = None
        self._mid_roll_asset_names = list()
        self._duration_in_seconds = None
        self.discriminator = None

        if event_type is not None:
            self.event_type = event_type
        if message is not None:
            self.message = message
        if mid_roll_asset_names is not None:
            self.mid_roll_asset_names = mid_roll_asset_names
        if duration_in_seconds is not None:
            self.duration_in_seconds = duration_in_seconds

    @property
    def openapi_types(self):
        types = {
            'event_type': 'LiveEncodingEventName',
            'message': 'string_types',
            'mid_roll_asset_names': 'list[string_types]',
            'duration_in_seconds': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'event_type': 'eventType',
            'message': 'message',
            'mid_roll_asset_names': 'midRollAssetNames',
            'duration_in_seconds': 'durationInSeconds'
        }
        return attributes

    @property
    def event_type(self):
        # type: () -> LiveEncodingEventName
        """Gets the event_type of this LiveEncodingStatsEventDetails.


        :return: The event_type of this LiveEncodingStatsEventDetails.
        :rtype: LiveEncodingEventName
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        # type: (LiveEncodingEventName) -> None
        """Sets the event_type of this LiveEncodingStatsEventDetails.


        :param event_type: The event_type of this LiveEncodingStatsEventDetails.
        :type: LiveEncodingEventName
        """

        if event_type is not None:
            if not isinstance(event_type, LiveEncodingEventName):
                raise TypeError("Invalid type for `event_type`, type has to be `LiveEncodingEventName`")

        self._event_type = event_type

    @property
    def message(self):
        # type: () -> string_types
        """Gets the message of this LiveEncodingStatsEventDetails.

        Short description of the event

        :return: The message of this LiveEncodingStatsEventDetails.
        :rtype: string_types
        """
        return self._message

    @message.setter
    def message(self, message):
        # type: (string_types) -> None
        """Sets the message of this LiveEncodingStatsEventDetails.

        Short description of the event

        :param message: The message of this LiveEncodingStatsEventDetails.
        :type: string_types
        """

        if message is not None:
            if not isinstance(message, string_types):
                raise TypeError("Invalid type for `message`, type has to be `string_types`")

        self._message = message

    @property
    def mid_roll_asset_names(self):
        # type: () -> list[string_types]
        """Gets the mid_roll_asset_names of this LiveEncodingStatsEventDetails.

        Name of the mid roll asset name

        :return: The mid_roll_asset_names of this LiveEncodingStatsEventDetails.
        :rtype: list[string_types]
        """
        return self._mid_roll_asset_names

    @mid_roll_asset_names.setter
    def mid_roll_asset_names(self, mid_roll_asset_names):
        # type: (list) -> None
        """Sets the mid_roll_asset_names of this LiveEncodingStatsEventDetails.

        Name of the mid roll asset name

        :param mid_roll_asset_names: The mid_roll_asset_names of this LiveEncodingStatsEventDetails.
        :type: list[string_types]
        """

        if mid_roll_asset_names is not None:
            if not isinstance(mid_roll_asset_names, list):
                raise TypeError("Invalid type for `mid_roll_asset_names`, type has to be `list[string_types]`")

        self._mid_roll_asset_names = mid_roll_asset_names

    @property
    def duration_in_seconds(self):
        # type: () -> float
        """Gets the duration_in_seconds of this LiveEncodingStatsEventDetails.

        Duration in seconds

        :return: The duration_in_seconds of this LiveEncodingStatsEventDetails.
        :rtype: float
        """
        return self._duration_in_seconds

    @duration_in_seconds.setter
    def duration_in_seconds(self, duration_in_seconds):
        # type: (float) -> None
        """Sets the duration_in_seconds of this LiveEncodingStatsEventDetails.

        Duration in seconds

        :param duration_in_seconds: The duration_in_seconds of this LiveEncodingStatsEventDetails.
        :type: float
        """

        if duration_in_seconds is not None:
            if not isinstance(duration_in_seconds, (float, int)):
                raise TypeError("Invalid type for `duration_in_seconds`, type has to be `float`")

        self._duration_in_seconds = duration_in_seconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingStatsEventDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitrate_selection_mode import BitrateSelectionMode
import pprint
import six


class StreamPerTitleFixedResolutionAndBitrateSettings(object):
    @poscheck_model
    def __init__(self,
                 min_bitrate=None,
                 max_bitrate=None,
                 bitrate_selection_mode=None,
                 low_complexity_boundary_for_max_bitrate=None,
                 high_complexity_boundary_for_max_bitrate=None):
        # type: (int, int, BitrateSelectionMode, int, int) -> None

        self._min_bitrate = None
        self._max_bitrate = None
        self._bitrate_selection_mode = None
        self._low_complexity_boundary_for_max_bitrate = None
        self._high_complexity_boundary_for_max_bitrate = None
        self.discriminator = None

        if min_bitrate is not None:
            self.min_bitrate = min_bitrate
        if max_bitrate is not None:
            self.max_bitrate = max_bitrate
        if bitrate_selection_mode is not None:
            self.bitrate_selection_mode = bitrate_selection_mode
        if low_complexity_boundary_for_max_bitrate is not None:
            self.low_complexity_boundary_for_max_bitrate = low_complexity_boundary_for_max_bitrate
        if high_complexity_boundary_for_max_bitrate is not None:
            self.high_complexity_boundary_for_max_bitrate = high_complexity_boundary_for_max_bitrate

    @property
    def openapi_types(self):
        types = {
            'min_bitrate': 'int',
            'max_bitrate': 'int',
            'bitrate_selection_mode': 'BitrateSelectionMode',
            'low_complexity_boundary_for_max_bitrate': 'int',
            'high_complexity_boundary_for_max_bitrate': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'min_bitrate': 'minBitrate',
            'max_bitrate': 'maxBitrate',
            'bitrate_selection_mode': 'bitrateSelectionMode',
            'low_complexity_boundary_for_max_bitrate': 'lowComplexityBoundaryForMaxBitrate',
            'high_complexity_boundary_for_max_bitrate': 'highComplexityBoundaryForMaxBitrate'
        }
        return attributes

    @property
    def min_bitrate(self):
        # type: () -> int
        """Gets the min_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        The minimum bitrate that will be used for that template.

        :return: The min_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :rtype: int
        """
        return self._min_bitrate

    @min_bitrate.setter
    def min_bitrate(self, min_bitrate):
        # type: (int) -> None
        """Sets the min_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        The minimum bitrate that will be used for that template.

        :param min_bitrate: The min_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :type: int
        """

        if min_bitrate is not None:
            if not isinstance(min_bitrate, int):
                raise TypeError("Invalid type for `min_bitrate`, type has to be `int`")

        self._min_bitrate = min_bitrate

    @property
    def max_bitrate(self):
        # type: () -> int
        """Gets the max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        The maximum bitrate that will be used for that template.

        :return: The max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :rtype: int
        """
        return self._max_bitrate

    @max_bitrate.setter
    def max_bitrate(self, max_bitrate):
        # type: (int) -> None
        """Sets the max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        The maximum bitrate that will be used for that template.

        :param max_bitrate: The max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :type: int
        """

        if max_bitrate is not None:
            if not isinstance(max_bitrate, int):
                raise TypeError("Invalid type for `max_bitrate`, type has to be `int`")

        self._max_bitrate = max_bitrate

    @property
    def bitrate_selection_mode(self):
        # type: () -> BitrateSelectionMode
        """Gets the bitrate_selection_mode of this StreamPerTitleFixedResolutionAndBitrateSettings.

        Bitrate selection mode

        :return: The bitrate_selection_mode of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :rtype: BitrateSelectionMode
        """
        return self._bitrate_selection_mode

    @bitrate_selection_mode.setter
    def bitrate_selection_mode(self, bitrate_selection_mode):
        # type: (BitrateSelectionMode) -> None
        """Sets the bitrate_selection_mode of this StreamPerTitleFixedResolutionAndBitrateSettings.

        Bitrate selection mode

        :param bitrate_selection_mode: The bitrate_selection_mode of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :type: BitrateSelectionMode
        """

        if bitrate_selection_mode is not None:
            if not isinstance(bitrate_selection_mode, BitrateSelectionMode):
                raise TypeError("Invalid type for `bitrate_selection_mode`, type has to be `BitrateSelectionMode`")

        self._bitrate_selection_mode = bitrate_selection_mode

    @property
    def low_complexity_boundary_for_max_bitrate(self):
        # type: () -> int
        """Gets the low_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        Low complexity boundary for max bitrate

        :return: The low_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :rtype: int
        """
        return self._low_complexity_boundary_for_max_bitrate

    @low_complexity_boundary_for_max_bitrate.setter
    def low_complexity_boundary_for_max_bitrate(self, low_complexity_boundary_for_max_bitrate):
        # type: (int) -> None
        """Sets the low_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        Low complexity boundary for max bitrate

        :param low_complexity_boundary_for_max_bitrate: The low_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :type: int
        """

        if low_complexity_boundary_for_max_bitrate is not None:
            if not isinstance(low_complexity_boundary_for_max_bitrate, int):
                raise TypeError("Invalid type for `low_complexity_boundary_for_max_bitrate`, type has to be `int`")

        self._low_complexity_boundary_for_max_bitrate = low_complexity_boundary_for_max_bitrate

    @property
    def high_complexity_boundary_for_max_bitrate(self):
        # type: () -> int
        """Gets the high_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        High complexity boundary for max bitrate

        :return: The high_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :rtype: int
        """
        return self._high_complexity_boundary_for_max_bitrate

    @high_complexity_boundary_for_max_bitrate.setter
    def high_complexity_boundary_for_max_bitrate(self, high_complexity_boundary_for_max_bitrate):
        # type: (int) -> None
        """Sets the high_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.

        High complexity boundary for max bitrate

        :param high_complexity_boundary_for_max_bitrate: The high_complexity_boundary_for_max_bitrate of this StreamPerTitleFixedResolutionAndBitrateSettings.
        :type: int
        """

        if high_complexity_boundary_for_max_bitrate is not None:
            if not isinstance(high_complexity_boundary_for_max_bitrate, int):
                raise TypeError("Invalid type for `high_complexity_boundary_for_max_bitrate`, type has to be `int`")

        self._high_complexity_boundary_for_max_bitrate = high_complexity_boundary_for_max_bitrate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamPerTitleFixedResolutionAndBitrateSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.input import Input
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.inputs.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.inputs.rtmp.rtmp_api import RtmpApi
from bitmovin_api_sdk.encoding.inputs.redundant_rtmp.redundant_rtmp_api import RedundantRtmpApi
from bitmovin_api_sdk.encoding.inputs.s3.s3_api import S3Api
from bitmovin_api_sdk.encoding.inputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.encoding.inputs.generic_s3.generic_s3_api import GenericS3Api
from bitmovin_api_sdk.encoding.inputs.local.local_api import LocalApi
from bitmovin_api_sdk.encoding.inputs.gcs.gcs_api import GcsApi
from bitmovin_api_sdk.encoding.inputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
from bitmovin_api_sdk.encoding.inputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.inputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.inputs.hls.hls_api import HlsApi
from bitmovin_api_sdk.encoding.inputs.sftp.sftp_api import SftpApi
from bitmovin_api_sdk.encoding.inputs.http.http_api import HttpApi
from bitmovin_api_sdk.encoding.inputs.https.https_api import HttpsApi
from bitmovin_api_sdk.encoding.inputs.aspera.aspera_api import AsperaApi
from bitmovin_api_sdk.encoding.inputs.akamai_netstorage.akamai_netstorage_api import AkamaiNetstorageApi
from bitmovin_api_sdk.encoding.inputs.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.inputs.zixi.zixi_api import ZixiApi
from bitmovin_api_sdk.encoding.inputs.direct_file_upload.direct_file_upload_api import DirectFileUploadApi
from bitmovin_api_sdk.encoding.inputs.input_list_query_params import InputListQueryParams


class InputsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InputsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.rtmp = RtmpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.redundant_rtmp = RedundantRtmpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3 = S3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3_role_based = S3RoleBasedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.generic_s3 = GenericS3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.local = LocalApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs = GcsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs_service_account = GcsServiceAccountApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.azure = AzureApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ftp = FtpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.hls = HlsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sftp = SftpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.http = HttpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.https = HttpsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.aspera = AsperaApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.akamai_netstorage = AkamaiNetstorageApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.srt = SrtApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.zixi = ZixiApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.direct_file_upload = DirectFileUploadApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> Input
        """Get Input Details

        :param input_id: Id of the Input
        :type input_id: string_types, required
        :return: Input details
        :rtype: Input
        """

        return self.api_client.get(
            '/encoding/inputs/{input_id}',
            path_params={'input_id': input_id},
            type=Input,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (InputListQueryParams, dict) -> Input
        """List all Inputs

        :param query_params: Query parameters
        :type query_params: InputListQueryParams
        :return: All input types with type information.
        :rtype: Input
        """

        return self.api_client.get(
            '/encoding/inputs',
            query_params=query_params,
            pagination_response=True,
            type=Input,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.media_stream import MediaStream
import pprint
import six


class VideoStream(MediaStream):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 position=None,
                 duration=None,
                 codec=None,
                 fps=None,
                 bitrate=None,
                 rate=None,
                 width=None,
                 height=None,
                 par=None,
                 rotation=None):
        # type: (string_types, int, float, string_types, string_types, string_types, int, int, int, float, int) -> None
        super(VideoStream, self).__init__(id_=id_, position=position, duration=duration, codec=codec)

        self._fps = None
        self._bitrate = None
        self._rate = None
        self._width = None
        self._height = None
        self._par = None
        self._rotation = None
        self.discriminator = None

        if fps is not None:
            self.fps = fps
        if bitrate is not None:
            self.bitrate = bitrate
        if rate is not None:
            self.rate = rate
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if par is not None:
            self.par = par
        if rotation is not None:
            self.rotation = rotation

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(VideoStream, self), 'openapi_types'):
            types = getattr(super(VideoStream, self), 'openapi_types')

        types.update({
            'fps': 'string_types',
            'bitrate': 'string_types',
            'rate': 'int',
            'width': 'int',
            'height': 'int',
            'par': 'float',
            'rotation': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(VideoStream, self), 'attribute_map'):
            attributes = getattr(super(VideoStream, self), 'attribute_map')

        attributes.update({
            'fps': 'fps',
            'bitrate': 'bitrate',
            'rate': 'rate',
            'width': 'width',
            'height': 'height',
            'par': 'par',
            'rotation': 'rotation'
        })
        return attributes

    @property
    def fps(self):
        # type: () -> string_types
        """Gets the fps of this VideoStream.

        Frame rate of the video

        :return: The fps of this VideoStream.
        :rtype: string_types
        """
        return self._fps

    @fps.setter
    def fps(self, fps):
        # type: (string_types) -> None
        """Sets the fps of this VideoStream.

        Frame rate of the video

        :param fps: The fps of this VideoStream.
        :type: string_types
        """

        if fps is not None:
            if not isinstance(fps, string_types):
                raise TypeError("Invalid type for `fps`, type has to be `string_types`")

        self._fps = fps

    @property
    def bitrate(self):
        # type: () -> string_types
        """Gets the bitrate of this VideoStream.

        Bitrate in bps

        :return: The bitrate of this VideoStream.
        :rtype: string_types
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (string_types) -> None
        """Sets the bitrate of this VideoStream.

        Bitrate in bps

        :param bitrate: The bitrate of this VideoStream.
        :type: string_types
        """

        if bitrate is not None:
            if not isinstance(bitrate, string_types):
                raise TypeError("Invalid type for `bitrate`, type has to be `string_types`")

        self._bitrate = bitrate

    @property
    def rate(self):
        # type: () -> int
        """Gets the rate of this VideoStream.

        Bitrate in bps (the same as bitrate, but represented as an integer value)

        :return: The rate of this VideoStream.
        :rtype: int
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (int) -> None
        """Sets the rate of this VideoStream.

        Bitrate in bps (the same as bitrate, but represented as an integer value)

        :param rate: The rate of this VideoStream.
        :type: int
        """

        if rate is not None:
            if not isinstance(rate, int):
                raise TypeError("Invalid type for `rate`, type has to be `int`")

        self._rate = rate

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this VideoStream.

        Width of the video (required)

        :return: The width of this VideoStream.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this VideoStream.

        Width of the video (required)

        :param width: The width of this VideoStream.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this VideoStream.

        Height of the video (required)

        :return: The height of this VideoStream.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this VideoStream.

        Height of the video (required)

        :param height: The height of this VideoStream.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def par(self):
        # type: () -> float
        """Gets the par of this VideoStream.

        Pixel aspect ratio of the video. Default is 1.0

        :return: The par of this VideoStream.
        :rtype: float
        """
        return self._par

    @par.setter
    def par(self, par):
        # type: (float) -> None
        """Sets the par of this VideoStream.

        Pixel aspect ratio of the video. Default is 1.0

        :param par: The par of this VideoStream.
        :type: float
        """

        if par is not None:
            if not isinstance(par, (float, int)):
                raise TypeError("Invalid type for `par`, type has to be `float`")

        self._par = par

    @property
    def rotation(self):
        # type: () -> int
        """Gets the rotation of this VideoStream.

        Rotation of the video for mobile devices. Default is 0.

        :return: The rotation of this VideoStream.
        :rtype: int
        """
        return self._rotation

    @rotation.setter
    def rotation(self, rotation):
        # type: (int) -> None
        """Sets the rotation of this VideoStream.

        Rotation of the video for mobile devices. Default is 0.

        :param rotation: The rotation of this VideoStream.
        :type: int
        """

        if rotation is not None:
            if not isinstance(rotation, int):
                raise TypeError("Invalid type for `rotation`, type has to be `int`")

        self._rotation = rotation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(VideoStream, self), "to_dict"):
            result = super(VideoStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_license import AnalyticsLicense
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.analytics.licenses.domains.domains_api import DomainsApi
from bitmovin_api_sdk.analytics.licenses.analytics_license_list_query_params import AnalyticsLicenseListQueryParams


class LicensesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LicensesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.domains = DomainsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, analytics_license, **kwargs):
        # type: (AnalyticsLicense, dict) -> AnalyticsLicense
        """Create Analytics License

        :param analytics_license: Analytics License to be created
        :type analytics_license: AnalyticsLicense, required
        :return: Created Analytics license
        :rtype: AnalyticsLicense
        """

        return self.api_client.post(
            '/analytics/licenses',
            analytics_license,
            type=AnalyticsLicense,
            **kwargs
        )

    def get(self, license_id, **kwargs):
        # type: (string_types, dict) -> AnalyticsLicense
        """Get License

        :param license_id: License id
        :type license_id: string_types, required
        :return: Analytics License
        :rtype: AnalyticsLicense
        """

        return self.api_client.get(
            '/analytics/licenses/{license_id}',
            path_params={'license_id': license_id},
            type=AnalyticsLicense,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AnalyticsLicenseListQueryParams, dict) -> AnalyticsLicense
        """List Analytics Licenses

        :param query_params: Query parameters
        :type query_params: AnalyticsLicenseListQueryParams
        :return: List of Analytics Licenses
        :rtype: AnalyticsLicense
        """

        return self.api_client.get(
            '/analytics/licenses',
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsLicense,
            **kwargs
        )

    def update(self, license_id, analytics_license, **kwargs):
        # type: (string_types, AnalyticsLicense, dict) -> AnalyticsLicense
        """Update Analytics License

        :param license_id: License id
        :type license_id: string_types, required
        :param analytics_license: Analytics License details to be updated
        :type analytics_license: AnalyticsLicense, required
        :return: Updated Analytics License
        :rtype: AnalyticsLicense
        """

        return self.api_client.put(
            '/analytics/licenses/{license_id}',
            analytics_license,
            path_params={'license_id': license_id},
            type=AnalyticsLicense,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyDigitalDownmixingPreferredMode(Enum):
    LO_RO = "LO_RO"
    LT_RT = "LT_RT"
    PRO_LOGIC_II = "PRO_LOGIC_II"



from bitmovin_api_sdk.encoding.encodings.scte35_triggers.scte35_triggers_api import Scte35TriggersApi
from bitmovin_api_sdk.encoding.encodings.scte35_triggers.scte35_trigger_list_query_params import Scte35TriggerListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.aws_account import AwsAccount
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.aws.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.aws.aws_account_list_query_params import AwsAccountListQueryParams


class AwsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AwsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.regions = RegionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, aws_account, **kwargs):
        # type: (AwsAccount, dict) -> AwsAccount
        """Add AWS Account

        :param aws_account: The AWS Account to be added
        :type aws_account: AwsAccount, required
        :return: AWS account
        :rtype: AwsAccount
        """

        return self.api_client.post(
            '/encoding/infrastructure/aws',
            aws_account,
            type=AwsAccount,
            **kwargs
        )

    def delete(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> AwsAccount
        """Delete AWS Account

        :param infrastructure_id: Id of the AWS account
        :type infrastructure_id: string_types, required
        :return: AWS account
        :rtype: AwsAccount
        """

        return self.api_client.delete(
            '/encoding/infrastructure/aws/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=AwsAccount,
            **kwargs
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> AwsAccount
        """AWS Account Details

        :param infrastructure_id: Id of the AWS account
        :type infrastructure_id: string_types, required
        :return: AWS account
        :rtype: AwsAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/aws/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=AwsAccount,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AwsAccountListQueryParams, dict) -> AwsAccount
        """List AWS Accounts

        :param query_params: Query parameters
        :type query_params: AwsAccountListQueryParams
        :return: List of AWS accounts
        :rtype: AwsAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/aws',
            query_params=query_params,
            pagination_response=True,
            type=AwsAccount,
            **kwargs
        )



from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.events.events_api import EventsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.events.live_encoding_stats_event_list_query_params import LiveEncodingStatsEventListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_encoding_codec import LiveEncodingCodec
from bitmovin_api_sdk.models.media_type import MediaType
import pprint
import six


class StreamInfosDetails(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 media_type=None,
                 width=None,
                 height=None,
                 rate=None,
                 codec=None,
                 samples_read_per_second_min=None,
                 samples_read_per_second_max=None,
                 samples_read_per_second_avg=None,
                 samples_backup_per_second_min=None,
                 samples_backup_per_second_max=None,
                 samples_backup_per_second_avg=None,
                 bytes_read_per_second_min=None,
                 bytes_read_per_second_max=None,
                 bytes_read_per_second_avg=None,
                 bytes_backup_per_second_min=None,
                 bytes_backup_per_second_max=None,
                 bytes_backup_per_second_avg=None):
        # type: (string_types, MediaType, int, int, float, LiveEncodingCodec, float, float, float, float, float, float, float, float, float, float, float, float) -> None

        self._id = None
        self._media_type = None
        self._width = None
        self._height = None
        self._rate = None
        self._codec = None
        self._samples_read_per_second_min = None
        self._samples_read_per_second_max = None
        self._samples_read_per_second_avg = None
        self._samples_backup_per_second_min = None
        self._samples_backup_per_second_max = None
        self._samples_backup_per_second_avg = None
        self._bytes_read_per_second_min = None
        self._bytes_read_per_second_max = None
        self._bytes_read_per_second_avg = None
        self._bytes_backup_per_second_min = None
        self._bytes_backup_per_second_max = None
        self._bytes_backup_per_second_avg = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if media_type is not None:
            self.media_type = media_type
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if rate is not None:
            self.rate = rate
        if codec is not None:
            self.codec = codec
        if samples_read_per_second_min is not None:
            self.samples_read_per_second_min = samples_read_per_second_min
        if samples_read_per_second_max is not None:
            self.samples_read_per_second_max = samples_read_per_second_max
        if samples_read_per_second_avg is not None:
            self.samples_read_per_second_avg = samples_read_per_second_avg
        if samples_backup_per_second_min is not None:
            self.samples_backup_per_second_min = samples_backup_per_second_min
        if samples_backup_per_second_max is not None:
            self.samples_backup_per_second_max = samples_backup_per_second_max
        if samples_backup_per_second_avg is not None:
            self.samples_backup_per_second_avg = samples_backup_per_second_avg
        if bytes_read_per_second_min is not None:
            self.bytes_read_per_second_min = bytes_read_per_second_min
        if bytes_read_per_second_max is not None:
            self.bytes_read_per_second_max = bytes_read_per_second_max
        if bytes_read_per_second_avg is not None:
            self.bytes_read_per_second_avg = bytes_read_per_second_avg
        if bytes_backup_per_second_min is not None:
            self.bytes_backup_per_second_min = bytes_backup_per_second_min
        if bytes_backup_per_second_max is not None:
            self.bytes_backup_per_second_max = bytes_backup_per_second_max
        if bytes_backup_per_second_avg is not None:
            self.bytes_backup_per_second_avg = bytes_backup_per_second_avg

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'media_type': 'MediaType',
            'width': 'int',
            'height': 'int',
            'rate': 'float',
            'codec': 'LiveEncodingCodec',
            'samples_read_per_second_min': 'float',
            'samples_read_per_second_max': 'float',
            'samples_read_per_second_avg': 'float',
            'samples_backup_per_second_min': 'float',
            'samples_backup_per_second_max': 'float',
            'samples_backup_per_second_avg': 'float',
            'bytes_read_per_second_min': 'float',
            'bytes_read_per_second_max': 'float',
            'bytes_read_per_second_avg': 'float',
            'bytes_backup_per_second_min': 'float',
            'bytes_backup_per_second_max': 'float',
            'bytes_backup_per_second_avg': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'media_type': 'mediaType',
            'width': 'width',
            'height': 'height',
            'rate': 'rate',
            'codec': 'codec',
            'samples_read_per_second_min': 'samplesReadPerSecondMin',
            'samples_read_per_second_max': 'samplesReadPerSecondMax',
            'samples_read_per_second_avg': 'samplesReadPerSecondAvg',
            'samples_backup_per_second_min': 'samplesBackupPerSecondMin',
            'samples_backup_per_second_max': 'samplesBackupPerSecondMax',
            'samples_backup_per_second_avg': 'samplesBackupPerSecondAvg',
            'bytes_read_per_second_min': 'bytesReadPerSecondMin',
            'bytes_read_per_second_max': 'bytesReadPerSecondMax',
            'bytes_read_per_second_avg': 'bytesReadPerSecondAvg',
            'bytes_backup_per_second_min': 'bytesBackupPerSecondMin',
            'bytes_backup_per_second_max': 'bytesBackupPerSecondMax',
            'bytes_backup_per_second_avg': 'bytesBackupPerSecondAvg'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this StreamInfosDetails.

        The id of the stream (required)

        :return: The id of this StreamInfosDetails.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this StreamInfosDetails.

        The id of the stream (required)

        :param id_: The id of this StreamInfosDetails.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def media_type(self):
        # type: () -> MediaType
        """Gets the media_type of this StreamInfosDetails.

        The media type of the stream (required)

        :return: The media_type of this StreamInfosDetails.
        :rtype: MediaType
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        # type: (MediaType) -> None
        """Sets the media_type of this StreamInfosDetails.

        The media type of the stream (required)

        :param media_type: The media_type of this StreamInfosDetails.
        :type: MediaType
        """

        if media_type is not None:
            if not isinstance(media_type, MediaType):
                raise TypeError("Invalid type for `media_type`, type has to be `MediaType`")

        self._media_type = media_type

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this StreamInfosDetails.

        The width of the stream, if it is a video stream

        :return: The width of this StreamInfosDetails.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this StreamInfosDetails.

        The width of the stream, if it is a video stream

        :param width: The width of this StreamInfosDetails.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this StreamInfosDetails.

        The height of the stream, if it is a video stream

        :return: The height of this StreamInfosDetails.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this StreamInfosDetails.

        The height of the stream, if it is a video stream

        :param height: The height of this StreamInfosDetails.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def rate(self):
        # type: () -> float
        """Gets the rate of this StreamInfosDetails.

        The rate (sample rate / fps) of the stream (required)

        :return: The rate of this StreamInfosDetails.
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (float) -> None
        """Sets the rate of this StreamInfosDetails.

        The rate (sample rate / fps) of the stream (required)

        :param rate: The rate of this StreamInfosDetails.
        :type: float
        """

        if rate is not None:
            if not isinstance(rate, (float, int)):
                raise TypeError("Invalid type for `rate`, type has to be `float`")

        self._rate = rate

    @property
    def codec(self):
        # type: () -> LiveEncodingCodec
        """Gets the codec of this StreamInfosDetails.

        The codec of the input stream (required)

        :return: The codec of this StreamInfosDetails.
        :rtype: LiveEncodingCodec
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (LiveEncodingCodec) -> None
        """Sets the codec of this StreamInfosDetails.

        The codec of the input stream (required)

        :param codec: The codec of this StreamInfosDetails.
        :type: LiveEncodingCodec
        """

        if codec is not None:
            if not isinstance(codec, LiveEncodingCodec):
                raise TypeError("Invalid type for `codec`, type has to be `LiveEncodingCodec`")

        self._codec = codec

    @property
    def samples_read_per_second_min(self):
        # type: () -> float
        """Gets the samples_read_per_second_min of this StreamInfosDetails.

        The minimum samples read per second within the last minute (required)

        :return: The samples_read_per_second_min of this StreamInfosDetails.
        :rtype: float
        """
        return self._samples_read_per_second_min

    @samples_read_per_second_min.setter
    def samples_read_per_second_min(self, samples_read_per_second_min):
        # type: (float) -> None
        """Sets the samples_read_per_second_min of this StreamInfosDetails.

        The minimum samples read per second within the last minute (required)

        :param samples_read_per_second_min: The samples_read_per_second_min of this StreamInfosDetails.
        :type: float
        """

        if samples_read_per_second_min is not None:
            if not isinstance(samples_read_per_second_min, (float, int)):
                raise TypeError("Invalid type for `samples_read_per_second_min`, type has to be `float`")

        self._samples_read_per_second_min = samples_read_per_second_min

    @property
    def samples_read_per_second_max(self):
        # type: () -> float
        """Gets the samples_read_per_second_max of this StreamInfosDetails.

        The maximum samples read per second within the last minute (required)

        :return: The samples_read_per_second_max of this StreamInfosDetails.
        :rtype: float
        """
        return self._samples_read_per_second_max

    @samples_read_per_second_max.setter
    def samples_read_per_second_max(self, samples_read_per_second_max):
        # type: (float) -> None
        """Sets the samples_read_per_second_max of this StreamInfosDetails.

        The maximum samples read per second within the last minute (required)

        :param samples_read_per_second_max: The samples_read_per_second_max of this StreamInfosDetails.
        :type: float
        """

        if samples_read_per_second_max is not None:
            if not isinstance(samples_read_per_second_max, (float, int)):
                raise TypeError("Invalid type for `samples_read_per_second_max`, type has to be `float`")

        self._samples_read_per_second_max = samples_read_per_second_max

    @property
    def samples_read_per_second_avg(self):
        # type: () -> float
        """Gets the samples_read_per_second_avg of this StreamInfosDetails.

        The average samples read per second within the last minute (required)

        :return: The samples_read_per_second_avg of this StreamInfosDetails.
        :rtype: float
        """
        return self._samples_read_per_second_avg

    @samples_read_per_second_avg.setter
    def samples_read_per_second_avg(self, samples_read_per_second_avg):
        # type: (float) -> None
        """Sets the samples_read_per_second_avg of this StreamInfosDetails.

        The average samples read per second within the last minute (required)

        :param samples_read_per_second_avg: The samples_read_per_second_avg of this StreamInfosDetails.
        :type: float
        """

        if samples_read_per_second_avg is not None:
            if not isinstance(samples_read_per_second_avg, (float, int)):
                raise TypeError("Invalid type for `samples_read_per_second_avg`, type has to be `float`")

        self._samples_read_per_second_avg = samples_read_per_second_avg

    @property
    def samples_backup_per_second_min(self):
        # type: () -> float
        """Gets the samples_backup_per_second_min of this StreamInfosDetails.

        The minimum amount of backup samples used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :return: The samples_backup_per_second_min of this StreamInfosDetails.
        :rtype: float
        """
        return self._samples_backup_per_second_min

    @samples_backup_per_second_min.setter
    def samples_backup_per_second_min(self, samples_backup_per_second_min):
        # type: (float) -> None
        """Sets the samples_backup_per_second_min of this StreamInfosDetails.

        The minimum amount of backup samples used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :param samples_backup_per_second_min: The samples_backup_per_second_min of this StreamInfosDetails.
        :type: float
        """

        if samples_backup_per_second_min is not None:
            if not isinstance(samples_backup_per_second_min, (float, int)):
                raise TypeError("Invalid type for `samples_backup_per_second_min`, type has to be `float`")

        self._samples_backup_per_second_min = samples_backup_per_second_min

    @property
    def samples_backup_per_second_max(self):
        # type: () -> float
        """Gets the samples_backup_per_second_max of this StreamInfosDetails.

        The maximum amount of backup samples used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :return: The samples_backup_per_second_max of this StreamInfosDetails.
        :rtype: float
        """
        return self._samples_backup_per_second_max

    @samples_backup_per_second_max.setter
    def samples_backup_per_second_max(self, samples_backup_per_second_max):
        # type: (float) -> None
        """Sets the samples_backup_per_second_max of this StreamInfosDetails.

        The maximum amount of backup samples used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :param samples_backup_per_second_max: The samples_backup_per_second_max of this StreamInfosDetails.
        :type: float
        """

        if samples_backup_per_second_max is not None:
            if not isinstance(samples_backup_per_second_max, (float, int)):
                raise TypeError("Invalid type for `samples_backup_per_second_max`, type has to be `float`")

        self._samples_backup_per_second_max = samples_backup_per_second_max

    @property
    def samples_backup_per_second_avg(self):
        # type: () -> float
        """Gets the samples_backup_per_second_avg of this StreamInfosDetails.

        The average amount of backup samples used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :return: The samples_backup_per_second_avg of this StreamInfosDetails.
        :rtype: float
        """
        return self._samples_backup_per_second_avg

    @samples_backup_per_second_avg.setter
    def samples_backup_per_second_avg(self, samples_backup_per_second_avg):
        # type: (float) -> None
        """Sets the samples_backup_per_second_avg of this StreamInfosDetails.

        The average amount of backup samples used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :param samples_backup_per_second_avg: The samples_backup_per_second_avg of this StreamInfosDetails.
        :type: float
        """

        if samples_backup_per_second_avg is not None:
            if not isinstance(samples_backup_per_second_avg, (float, int)):
                raise TypeError("Invalid type for `samples_backup_per_second_avg`, type has to be `float`")

        self._samples_backup_per_second_avg = samples_backup_per_second_avg

    @property
    def bytes_read_per_second_min(self):
        # type: () -> float
        """Gets the bytes_read_per_second_min of this StreamInfosDetails.

        The minimum bytes read per second within the last minute (required)

        :return: The bytes_read_per_second_min of this StreamInfosDetails.
        :rtype: float
        """
        return self._bytes_read_per_second_min

    @bytes_read_per_second_min.setter
    def bytes_read_per_second_min(self, bytes_read_per_second_min):
        # type: (float) -> None
        """Sets the bytes_read_per_second_min of this StreamInfosDetails.

        The minimum bytes read per second within the last minute (required)

        :param bytes_read_per_second_min: The bytes_read_per_second_min of this StreamInfosDetails.
        :type: float
        """

        if bytes_read_per_second_min is not None:
            if not isinstance(bytes_read_per_second_min, (float, int)):
                raise TypeError("Invalid type for `bytes_read_per_second_min`, type has to be `float`")

        self._bytes_read_per_second_min = bytes_read_per_second_min

    @property
    def bytes_read_per_second_max(self):
        # type: () -> float
        """Gets the bytes_read_per_second_max of this StreamInfosDetails.

        The maximum bytes read per second within the last minute (required)

        :return: The bytes_read_per_second_max of this StreamInfosDetails.
        :rtype: float
        """
        return self._bytes_read_per_second_max

    @bytes_read_per_second_max.setter
    def bytes_read_per_second_max(self, bytes_read_per_second_max):
        # type: (float) -> None
        """Sets the bytes_read_per_second_max of this StreamInfosDetails.

        The maximum bytes read per second within the last minute (required)

        :param bytes_read_per_second_max: The bytes_read_per_second_max of this StreamInfosDetails.
        :type: float
        """

        if bytes_read_per_second_max is not None:
            if not isinstance(bytes_read_per_second_max, (float, int)):
                raise TypeError("Invalid type for `bytes_read_per_second_max`, type has to be `float`")

        self._bytes_read_per_second_max = bytes_read_per_second_max

    @property
    def bytes_read_per_second_avg(self):
        # type: () -> float
        """Gets the bytes_read_per_second_avg of this StreamInfosDetails.

        The average bytes read per second within the last minute (required)

        :return: The bytes_read_per_second_avg of this StreamInfosDetails.
        :rtype: float
        """
        return self._bytes_read_per_second_avg

    @bytes_read_per_second_avg.setter
    def bytes_read_per_second_avg(self, bytes_read_per_second_avg):
        # type: (float) -> None
        """Sets the bytes_read_per_second_avg of this StreamInfosDetails.

        The average bytes read per second within the last minute (required)

        :param bytes_read_per_second_avg: The bytes_read_per_second_avg of this StreamInfosDetails.
        :type: float
        """

        if bytes_read_per_second_avg is not None:
            if not isinstance(bytes_read_per_second_avg, (float, int)):
                raise TypeError("Invalid type for `bytes_read_per_second_avg`, type has to be `float`")

        self._bytes_read_per_second_avg = bytes_read_per_second_avg

    @property
    def bytes_backup_per_second_min(self):
        # type: () -> float
        """Gets the bytes_backup_per_second_min of this StreamInfosDetails.

        The minimum amount of backup bytes used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :return: The bytes_backup_per_second_min of this StreamInfosDetails.
        :rtype: float
        """
        return self._bytes_backup_per_second_min

    @bytes_backup_per_second_min.setter
    def bytes_backup_per_second_min(self, bytes_backup_per_second_min):
        # type: (float) -> None
        """Sets the bytes_backup_per_second_min of this StreamInfosDetails.

        The minimum amount of backup bytes used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :param bytes_backup_per_second_min: The bytes_backup_per_second_min of this StreamInfosDetails.
        :type: float
        """

        if bytes_backup_per_second_min is not None:
            if not isinstance(bytes_backup_per_second_min, (float, int)):
                raise TypeError("Invalid type for `bytes_backup_per_second_min`, type has to be `float`")

        self._bytes_backup_per_second_min = bytes_backup_per_second_min

    @property
    def bytes_backup_per_second_max(self):
        # type: () -> float
        """Gets the bytes_backup_per_second_max of this StreamInfosDetails.

        The maximum amount of backup bytes used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :return: The bytes_backup_per_second_max of this StreamInfosDetails.
        :rtype: float
        """
        return self._bytes_backup_per_second_max

    @bytes_backup_per_second_max.setter
    def bytes_backup_per_second_max(self, bytes_backup_per_second_max):
        # type: (float) -> None
        """Sets the bytes_backup_per_second_max of this StreamInfosDetails.

        The maximum amount of backup bytes used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :param bytes_backup_per_second_max: The bytes_backup_per_second_max of this StreamInfosDetails.
        :type: float
        """

        if bytes_backup_per_second_max is not None:
            if not isinstance(bytes_backup_per_second_max, (float, int)):
                raise TypeError("Invalid type for `bytes_backup_per_second_max`, type has to be `float`")

        self._bytes_backup_per_second_max = bytes_backup_per_second_max

    @property
    def bytes_backup_per_second_avg(self):
        # type: () -> float
        """Gets the bytes_backup_per_second_avg of this StreamInfosDetails.

        The average amount of backup bytes used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :return: The bytes_backup_per_second_avg of this StreamInfosDetails.
        :rtype: float
        """
        return self._bytes_backup_per_second_avg

    @bytes_backup_per_second_avg.setter
    def bytes_backup_per_second_avg(self, bytes_backup_per_second_avg):
        # type: (float) -> None
        """Sets the bytes_backup_per_second_avg of this StreamInfosDetails.

        The average amount of backup bytes used per second within the last minute. This will be written when no live stream is ingested. The last picture will be repeated with silent audio. (required)

        :param bytes_backup_per_second_avg: The bytes_backup_per_second_avg of this StreamInfosDetails.
        :type: float
        """

        if bytes_backup_per_second_avg is not None:
            if not isinstance(bytes_backup_per_second_avg, (float, int)):
                raise TypeError("Invalid type for `bytes_backup_per_second_avg`, type has to be `float`")

        self._bytes_backup_per_second_avg = bytes_backup_per_second_avg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamInfosDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.azure_input import AzureInput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.inputs.azure.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.azure.azure_input_list_query_params import AzureInputListQueryParams


class AzureApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AzureApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, azure_input, **kwargs):
        # type: (AzureInput, dict) -> AzureInput
        """Create Azure Input

        :param azure_input: The Azure input to be created
        :type azure_input: AzureInput, required
        :return: Azure input
        :rtype: AzureInput
        """

        return self.api_client.post(
            '/encoding/inputs/azure',
            azure_input,
            type=AzureInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> AzureInput
        """Delete Azure Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: AzureInput
        """

        return self.api_client.delete(
            '/encoding/inputs/azure/{input_id}',
            path_params={'input_id': input_id},
            type=AzureInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> AzureInput
        """Azure Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Azure input
        :rtype: AzureInput
        """

        return self.api_client.get(
            '/encoding/inputs/azure/{input_id}',
            path_params={'input_id': input_id},
            type=AzureInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AzureInputListQueryParams, dict) -> AzureInput
        """List Azure Inputs

        :param query_params: Query parameters
        :type query_params: AzureInputListQueryParams
        :return: List of Azure inputs
        :rtype: AzureInput
        """

        return self.api_client.get(
            '/encoding/inputs/azure',
            query_params=query_params,
            pagination_response=True,
            type=AzureInput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ColorSpace(Enum):
    UNSPECIFIED = "UNSPECIFIED"
    RGB = "RGB"
    BT709 = "BT709"
    FCC = "FCC"
    BT470BG = "BT470BG"
    SMPTE170M = "SMPTE170M"
    SMPTE240M = "SMPTE240M"
    YCGCO = "YCGCO"
    YCOCG = "YCOCG"
    BT2020_NCL = "BT2020_NCL"
    BT2020_CL = "BT2020_CL"
    SMPTE2085 = "SMPTE2085"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_video_sync_mode import AudioVideoSyncMode
import pprint
import six


class Tweaks(object):
    @poscheck_model
    def __init__(self,
                 audio_video_sync_mode=None):
        # type: (AudioVideoSyncMode) -> None

        self._audio_video_sync_mode = None
        self.discriminator = None

        if audio_video_sync_mode is not None:
            self.audio_video_sync_mode = audio_video_sync_mode

    @property
    def openapi_types(self):
        types = {
            'audio_video_sync_mode': 'AudioVideoSyncMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'audio_video_sync_mode': 'audioVideoSyncMode'
        }
        return attributes

    @property
    def audio_video_sync_mode(self):
        # type: () -> AudioVideoSyncMode
        """Gets the audio_video_sync_mode of this Tweaks.

        Different modes for syncing the start and end of audio input streams with the video inputs. This feature does not work with Dolby Digital (Plus) or Dolby Atmos.

        :return: The audio_video_sync_mode of this Tweaks.
        :rtype: AudioVideoSyncMode
        """
        return self._audio_video_sync_mode

    @audio_video_sync_mode.setter
    def audio_video_sync_mode(self, audio_video_sync_mode):
        # type: (AudioVideoSyncMode) -> None
        """Sets the audio_video_sync_mode of this Tweaks.

        Different modes for syncing the start and end of audio input streams with the video inputs. This feature does not work with Dolby Digital (Plus) or Dolby Atmos.

        :param audio_video_sync_mode: The audio_video_sync_mode of this Tweaks.
        :type: AudioVideoSyncMode
        """

        if audio_video_sync_mode is not None:
            if not isinstance(audio_video_sync_mode, AudioVideoSyncMode):
                raise TypeError("Invalid type for `audio_video_sync_mode`, type has to be `AudioVideoSyncMode`")

        self._audio_video_sync_mode = audio_video_sync_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tweaks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
